.. HDX Python API documentation master file.

HDX Python API Documentation
============================

The HDX Python Library is designed to enable you to easily develop code that interacts with the Humanitarian Data Exchange platform. The major goal of the library is to make interacting with HDX as simple as possible for the end user.

Contents
--------

.. toctree::
   :maxdepth: 1

   source/hdx.rst
   source/hdx.data.rst
   source/hdx.facades.rst

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
